==> activity-custom-center-api-0.3.61-sources.jar: cn/com/duiba/activity/custom/center/api/dto/xiangshang/XiangShangRecordDto.java <==
package cn.com.duiba.activity.custom.center.api.dto.xiangshang;

import java.io.Serializable;
import java.util.Date;

/**
 * @author: pengyi
 * @description:
 * @date: 2022/4/25 上午11:32
 */
public class XiangShangRecordDto implements Serializable {

    private static final long serialVersionUID = -1545490574377063171L;

    /** 创建 */
    public static final int STATUS_CREATE = 0;
    /** 充值中 */
    public static final int STATUS_CHARGING = 1;
    /** 充值成功 */
    public static final int STATUS_SUCCESS = 2;
    /** 充值成功 */
    public static final int STATUS_FAIL = 3;
    /** 充值异常 */
    public static final int STATUS_EXCEPTION = 99;
    /**
     * 主键
     */
    private Long id;

    /**
     * 批次id
     */
    private Long batchId;

    /**
     * 手机号
     */
    private String phone;

    /**
     * 充值金额
     */
    private Long rechargeAmount;

    /**
     * 0-创建，1-充值中，2-充值成功，3-向上充值失败，99-向上响应异常
     */
    private Integer status;

    /**
     * 兑吧订单号
     */
    private String orderNum;

    /**
     * 向上订单号
     */
    private String upOrderNum;

    /**
     * 运营商
     */
    private String operator;

    /**
     * 操作人
     */
    private String adminName;

    /**
     * 操作备注
     */
    private String remark;

    /**
     * 失败原因
     */
    private String errorMsg;

    /**
     * 充值账户
     */
    private String chargeType;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getBatchId() {
        return batchId;
    }

    public void setBatchId(Long batchId) {
        this.batchId = batchId;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public Long getRechargeAmount() {
        return rechargeAmount;
    }

    public void setRechargeAmount(Long rechargeAmount) {
        this.rechargeAmount = rechargeAmount;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }

    public String getUpOrderNum() {
        return upOrderNum;
    }

    public void setUpOrderNum(String upOrderNum) {
        this.upOrderNum = upOrderNum;
    }

    public String getOperator() {
        return operator;
    }

    public void setOperator(String operator) {
        this.operator = operator;
    }

    public String getAdminName() {
        return adminName;
    }

    public void setAdminName(String adminName) {
        this.adminName = adminName;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public String getChargeType() {
        return chargeType;
    }

    public void setChargeType(String chargeType) {
        this.chargeType = chargeType;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> activity-custom-center-api-1.0.39-1-20251210.061738-1-sources.jar: cn/com/duiba/activity/custom/center/api/dto/xiangshang/XiangShangRecordDto.java <==
package cn.com.duiba.activity.custom.center.api.dto.xiangshang;

import java.io.Serializable;
import java.util.Date;

/**
 * @author: pengyi
 * @description:
 * @date: 2022/4/25 上午11:32
 */
public class XiangShangRecordDto implements Serializable {

    private static final long serialVersionUID = -1545490574377063171L;

    /** 创建 */
    public static final int STATUS_CREATE = 0;
    /** 充值中 */
    public static final int STATUS_CHARGING = 1;
    /** 充值成功 */
    public static final int STATUS_SUCCESS = 2;
    /** 充值成功 */
    public static final int STATUS_FAIL = 3;
    /** 充值异常 */
    public static final int STATUS_EXCEPTION = 99;
    /**
     * 主键
     */
    private Long id;

    /**
     * 批次id
     */
    private Long batchId;

    /**
     * 手机号
     */
    private String phone;

    /**
     * 充值金额
     */
    private Long rechargeAmount;

    /**
     * 0-创建，1-充值中，2-充值成功，3-向上充值失败，99-向上响应异常
     */
    private Integer status;

    /**
     * 兑吧订单号
     */
    private String orderNum;

    /**
     * 向上订单号
     */
    private String upOrderNum;

    /**
     * 运营商
     */
    private String operator;

    /**
     * 操作人
     */
    private String adminName;

    /**
     * 操作备注
     */
    private String remark;

    /**
     * 失败原因
     */
    private String errorMsg;

    /**
     * 充值账户
     */
    private String chargeType;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;
    /**
     *  供应商
     * @see cn.com.duiba.activity.custom.center.api.enums.phonebill.PhonebillSupplierEnum
     */
    private String supplier;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getBatchId() {
        return batchId;
    }

    public void setBatchId(Long batchId) {
        this.batchId = batchId;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public Long getRechargeAmount() {
        return rechargeAmount;
    }

    public void setRechargeAmount(Long rechargeAmount) {
        this.rechargeAmount = rechargeAmount;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }

    public String getUpOrderNum() {
        return upOrderNum;
    }

    public void setUpOrderNum(String upOrderNum) {
        this.upOrderNum = upOrderNum;
    }

    public String getOperator() {
        return operator;
    }

    public void setOperator(String operator) {
        this.operator = operator;
    }

    public String getAdminName() {
        return adminName;
    }

    public void setAdminName(String adminName) {
        this.adminName = adminName;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public String getChargeType() {
        return chargeType;
    }

    public void setChargeType(String chargeType) {
        this.chargeType = chargeType;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getSupplier() {
        return supplier;
    }

    public void setSupplier(String supplier) {
        this.supplier = supplier;
    }
}
